==> qtjambi-serialbus-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiSerialBus/QCanSignalDescription_MultiplexValueRange_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtSerialBus/qcansignaldescription.h>
#include <QtCore/QVariant>
#include <QtCore/qdebug.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QCanSignalDescription_MultiplexValueRange(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCanSignalDescription::MultiplexValueRange")
    QCanSignalDescription::MultiplexValueRange *_ptr = reinterpret_cast<QCanSignalDescription::MultiplexValueRange *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QCanSignalDescription_MultiplexValueRange_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QCanSignalDescription::MultiplexValueRange *__qt_this = new(__qtjambi_ptr) QCanSignalDescription::MultiplexValueRange();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QCanSignalDescription::MultiplexValueRange
void __qt_destruct_QCanSignalDescription_MultiplexValueRange(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCanSignalDescription::MultiplexValueRange")
    reinterpret_cast<QCanSignalDescription::MultiplexValueRange*>(ptr)->~MultiplexValueRange();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCanSignalDescription::MultiplexValueRange::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanSignalDescription_00024MultiplexValueRange_initialize_1native__Lio_qt_serialbus_QCanSignalDescription_00024MultiplexValueRange_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCanSignalDescription::MultiplexValueRange::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCanSignalDescription_MultiplexValueRange_0, sizeof(QCanSignalDescription::MultiplexValueRange), typeid(QCanSignalDescription::MultiplexValueRange), false, &deleter_QCanSignalDescription_MultiplexValueRange, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCanSignalDescription::MultiplexValueRange::operator==(QCanSignalDescription::MultiplexValueRange,QCanSignalDescription::MultiplexValueRange)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanSignalDescription_00024MultiplexValueRange_operator_1equal_1native_1cref_1QCanSignalDescription_1MultiplexValueRange__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QCanSignalDescription::MultiplexValueRange *__qt_this = QtJambiAPI::objectFromNativeId<QCanSignalDescription::MultiplexValueRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCanSignalDescription::MultiplexValueRange::operator==(QCanSignalDescription::MultiplexValueRange,QCanSignalDescription::MultiplexValueRange)", __qt_this)
        const QCanSignalDescription::MultiplexValueRange& __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QCanSignalDescription::MultiplexValueRange>(rhs1);
        __java_return_value = (*__qt_this) == __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanSignalDescription_00024MultiplexValueRange_setMaximum_1native_1cref_1QVariant__JLjava_lang_Object_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject maximum0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanSignalDescription::MultiplexValueRange *__qt_this = QtJambiAPI::objectFromNativeId<QCanSignalDescription::MultiplexValueRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QVariant  __qt_maximum0 = qtjambi_cast<QVariant >(__jni_env, maximum0);
        __qt_this->maximum = __qt_maximum0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanSignalDescription_00024MultiplexValueRange_maximum_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanSignalDescription::MultiplexValueRange *__qt_this = QtJambiAPI::objectFromNativeId<QCanSignalDescription::MultiplexValueRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QVariant&  __qt_value = __qt_this->maximum;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanSignalDescription_00024MultiplexValueRange_setMinimum_1native_1cref_1QVariant__JLjava_lang_Object_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject minimum0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanSignalDescription::MultiplexValueRange *__qt_this = QtJambiAPI::objectFromNativeId<QCanSignalDescription::MultiplexValueRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QVariant  __qt_minimum0 = qtjambi_cast<QVariant >(__jni_env, minimum0);
        __qt_this->minimum = __qt_minimum0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanSignalDescription_00024MultiplexValueRange_minimum_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanSignalDescription::MultiplexValueRange *__qt_this = QtJambiAPI::objectFromNativeId<QCanSignalDescription::MultiplexValueRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QVariant&  __qt_value = __qt_this->minimum;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

#include <QtCore/QDebug>
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanSignalDescription_00024MultiplexValueRange_toString_1native)(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value = nullptr;
    QTJAMBI_TRY {
        QCanSignalDescription::MultiplexValueRange *__qt_this = QtJambiAPI::objectFromNativeId<QCanSignalDescription::MultiplexValueRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString res;
        QDebug(&res).noquote() << *__qt_this;
        if(!res.isEmpty() && res.back().isSpace())
            res = res.trimmed();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, res);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanSignalDescription_00024MultiplexValueRange_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QCanSignalDescription::MultiplexValueRange *__qt_this = QtJambiAPI::objectFromNativeId<QCanSignalDescription::MultiplexValueRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCanSignalDescription_MultiplexValueRange(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QCanSignalDescription::MultiplexValueRange>("QCanSignalDescription::MultiplexValueRange", "io/qt/serialbus/QCanSignalDescription$MultiplexValueRange");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCanSignalDescription_MultiplexValueRange, {
        ConstructorInfo(&__qt_construct_QCanSignalDescription_MultiplexValueRange_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCanSignalDescription_MultiplexValueRange);
    registerMetaType<QCanSignalDescription::MultiplexValueRange>("QCanSignalDescription::MultiplexValueRange");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-serialbus-debuginfo-linux-x64-6.5.4.jar: sources/QtJambiSerialBus/QCanSignalDescription_MultiplexValueRange_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtSerialBus/qcansignaldescription.h>
#include <QtCore/QVariant>
#include <QtCore/qdebug.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QCanSignalDescription_MultiplexValueRange(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCanSignalDescription::MultiplexValueRange")
    QCanSignalDescription::MultiplexValueRange *_ptr = reinterpret_cast<QCanSignalDescription::MultiplexValueRange *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QCanSignalDescription_MultiplexValueRange_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QCanSignalDescription::MultiplexValueRange *__qt_this = new(__qtjambi_ptr) QCanSignalDescription::MultiplexValueRange();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QCanSignalDescription::MultiplexValueRange
void __qt_destruct_QCanSignalDescription_MultiplexValueRange(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCanSignalDescription::MultiplexValueRange")
    reinterpret_cast<QCanSignalDescription::MultiplexValueRange*>(ptr)->~MultiplexValueRange();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCanSignalDescription::MultiplexValueRange::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanSignalDescription_00024MultiplexValueRange_initialize_1native__Lio_qt_serialbus_QCanSignalDescription_00024MultiplexValueRange_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCanSignalDescription::MultiplexValueRange::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCanSignalDescription_MultiplexValueRange_0, sizeof(QCanSignalDescription::MultiplexValueRange), typeid(QCanSignalDescription::MultiplexValueRange), false, &deleter_QCanSignalDescription_MultiplexValueRange, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCanSignalDescription::MultiplexValueRange::operator==(QCanSignalDescription::MultiplexValueRange,QCanSignalDescription::MultiplexValueRange)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanSignalDescription_00024MultiplexValueRange_equals_1native_1cref_1QCanSignalDescription_1MultiplexValueRange__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QCanSignalDescription::MultiplexValueRange *__qt_this = QtJambiAPI::objectFromNativeId<QCanSignalDescription::MultiplexValueRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCanSignalDescription::MultiplexValueRange::operator==(QCanSignalDescription::MultiplexValueRange,QCanSignalDescription::MultiplexValueRange)", __qt_this)
        const QCanSignalDescription::MultiplexValueRange& __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QCanSignalDescription::MultiplexValueRange>(rhs1);
        __java_return_value = (*__qt_this) == __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanSignalDescription_00024MultiplexValueRange_setMaximum_1native_1cref_1QVariant__JLjava_lang_Object_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject maximum0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanSignalDescription::MultiplexValueRange *__qt_this = QtJambiAPI::objectFromNativeId<QCanSignalDescription::MultiplexValueRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QVariant  __qt_maximum0 = qtjambi_cast<QVariant >(__jni_env, maximum0);
        __qt_this->maximum = __qt_maximum0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanSignalDescription_00024MultiplexValueRange_maximum_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanSignalDescription::MultiplexValueRange *__qt_this = QtJambiAPI::objectFromNativeId<QCanSignalDescription::MultiplexValueRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QVariant&  __qt_value = __qt_this->maximum;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanSignalDescription_00024MultiplexValueRange_setMinimum_1native_1cref_1QVariant__JLjava_lang_Object_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject minimum0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanSignalDescription::MultiplexValueRange *__qt_this = QtJambiAPI::objectFromNativeId<QCanSignalDescription::MultiplexValueRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QVariant  __qt_minimum0 = qtjambi_cast<QVariant >(__jni_env, minimum0);
        __qt_this->minimum = __qt_minimum0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanSignalDescription_00024MultiplexValueRange_minimum_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanSignalDescription::MultiplexValueRange *__qt_this = QtJambiAPI::objectFromNativeId<QCanSignalDescription::MultiplexValueRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QVariant&  __qt_value = __qt_this->minimum;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

#include <QtCore/QDebug>
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanSignalDescription_00024MultiplexValueRange_toString_1native)(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value = nullptr;
    QTJAMBI_TRY {
        QCanSignalDescription::MultiplexValueRange *__qt_this = QtJambiAPI::objectFromNativeId<QCanSignalDescription::MultiplexValueRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString res;
        QDebug(&res).noquote() << *__qt_this;
        if(!res.isEmpty() && res.back().isSpace())
            res = res.trimmed();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, res);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanSignalDescription_00024MultiplexValueRange_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QCanSignalDescription::MultiplexValueRange *__qt_this = QtJambiAPI::objectFromNativeId<QCanSignalDescription::MultiplexValueRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCanSignalDescription_MultiplexValueRange(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QCanSignalDescription::MultiplexValueRange>("QCanSignalDescription::MultiplexValueRange", "io/qt/serialbus/QCanSignalDescription$MultiplexValueRange");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCanSignalDescription_MultiplexValueRange, {
        ConstructorInfo(&__qt_construct_QCanSignalDescription_MultiplexValueRange_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCanSignalDescription_MultiplexValueRange);
    registerMetaType<QCanSignalDescription::MultiplexValueRange>("QCanSignalDescription::MultiplexValueRange");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
